This function calculates the tetrachoric correlations between pairs of variables
in a given data frame. It returns a list containing a data frame with the tetrachoric
correlation coefficients, and the sum of the tetrachoric correlations if the
input variable was in p-value form.
Usage
tetracorr(data, varlist)
Value
list containing a data frame with tetrachoric correlation coefficients,
and the sum of the tetrachoric correlations if the input variable was in
p-value form.
Arguments
data
data frame with "markname" and study names as column names.
varlist
character vector of study names to include in the meta-analysis.